==> deepin-repair-tools_1.0.9.orig.tar.xz: deepin-repair-tools-1.0.9/translations/deepin-repair-tools_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Riparazione DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Mostra dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Nascondi dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Impossibile installare o aggiornare le applicazioni</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair succeeded</source>
        <translation>Riparazione completata</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Pulizia disco</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partizione di Sistema</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Pulizia</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="152"/>
        <source>%1 (on %2)</source>
        <translation>%1 (su %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="191"/>
        <source>Cleaning %1</source>
        <translation>Pulizia %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="237"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 è stato ripulito</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Riparazione Boot</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Mostra dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Nascondi dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Impossibile trovare il menu di boot per entrare nel Sistema</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair succeeded</source>
        <translation>Riparazione completata</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Reset password</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Conferma password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Inserisci una nuova password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>The two passwords don&apos;t match</source>
        <translation>Le due password non coincidono</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="128"/>
        <source>Reset password successfully</source>
        <translation>Reset della password completata</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="154"/>
        <source>Forgot login password</source>
        <translation>Password di login dimenticata</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="142"/>
        <source>%1 (on %2)</source>
        <translation>%1 (su %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Riparazione dei privilegi</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Impossibile entrare nel desktop per via di un errore di privilegi</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="72"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="91"/>
        <source>Reset privilege successfully</source>
        <translation>Reset dei privilegi completato</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="94"/>
        <source>Reset privilege failed</source>
        <translation>Ripristino privilegi fallito</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Controllo stato hard disk, attendere prego...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="36"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="40"/>
        <source>Restart Now</source>
        <translation>Riavvia ora</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="139"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Errore nella partizione %1 dell&apos;hard disk, per cortesia riparala</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="151"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Per cortesia riavvia il tuo computer per completare la riparazione</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="177"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Riparazione hard disk, attendere prego...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="140"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>La riparazione potrebbe causare perdita di dati, conferma per continuare</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="38"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>Repair succeeded</source>
        <translation>Riparazione completata</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="156"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Repair</source>
        <translation>Deepin Repair</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="46"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Repair è un tool utile all&apos;utenza per la correzione rapida di alcune anomalie di Sistema, come l&apos;identificazione degli hard disk, la pulizia dei dischi, la riparazione DPKG, riparazione del Boot, la riparazione dei privilegi, ripristino password, ecc.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
</TS>

==> deepin-repair-tools_1.0.14.orig.tar.xz: deepin-repair-tools-1.0.14/translations/deepin-repair-tools_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Riparazione DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Mostra dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Nascondi dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Impossibile installare o aggiornare le applicazioni</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair successful</source>
        <translation>Riparazione completata</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Pulizia disco</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partizione di Sistema</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Pulizia</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="153"/>
        <source>%1 (on %2)</source>
        <translation>%1 (su %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="192"/>
        <source>Cleaning %1</source>
        <translation>Pulizia %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="238"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 è stato ripulito</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Riparazione Boot</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Mostra dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Nascondi dettagli</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Impossibile trovare il menu di boot per entrare nel Sistema</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair successful</source>
        <translation>Riparazione completata</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Reset password</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Conferma password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Inserisci una nuova password</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>Passwords do not match</source>
        <translation>Le password non corrispondono</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="130"/>
        <source>Reset password successfully</source>
        <translation>Reset della password completata</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="156"/>
        <source>Forgot login password</source>
        <translation>Password di login dimenticata</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="144"/>
        <source>%1 (on %2)</source>
        <translation>%1 (su %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Riparazione dei privilegi</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Impossibile entrare nel desktop per via di un errore di privilegi</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="71"/>
        <source>Repairing, please wait...</source>
        <translation>Riparazione in corso, attendere prego...</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="90"/>
        <source>Reset privilege successfully</source>
        <translation>Reset dei privilegi completato</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="93"/>
        <source>Reset failed</source>
        <translation>Ripristino fallito</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Controllo stato hard disk, attendere prego...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="37"/>
        <source>Repair</source>
        <translation>Ripara</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="41"/>
        <source>Restart Now</source>
        <translation>Riavvia ora</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="149"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Errore nella partizione %1 dell&apos;hard disk, per cortesia riparala</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="160"/>
        <source>Repair successful</source>
        <translation>Riparazione completata</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="161"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Per cortesia riavvia il tuo computer per completare la riparazione</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="187"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Riparazione hard disk, attendere prego...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>La riparazione potrebbe causare perdita di dati, conferma per continuare</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="39"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="166"/>
        <source>Repair failed</source>
        <translation>Riparazione fallita</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Repair</source>
        <translation>Deepin Repair</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="48"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Repair è un tool utile all&apos;utenza per la correzione rapida di alcune anomalie di Sistema, come l&apos;identificazione degli hard disk, la pulizia dei dischi, la riparazione DPKG, riparazione del Boot, la riparazione dei privilegi, ripristino password, ecc.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
</TS>
